<?php

/**
 * Simple Machines Forum (SMF)
 *
 * @package SMF
 * @author Simple Machines http://www.simplemachines.org
 * @copyright 2011 Simple Machines
 * @license http://www.simplemachines.org/about/smf/license.php BSD
 *
 * @version 2.0
 */

if (!defined('SMF'))
	die('Hacking attempt...');

/*	This file maintains all XML-based interaction (mainly XMLhttp).

	void GetJumpTo()

*/

function XMLhttpMain()
{
	loadTemplate('Xml');

	$sub_actions = array(
		'jumpto' => array(
			'function' => 'GetJumpTo',
		),
		'messageicons' => array(
			'function' => 'ListMessageIcons',
		),
		'ordercustomprofilefields' => array(
			'function' => 'OrderCustomProfileFields',
		),
	);
	if (!isset($_REQUEST['sa'], $sub_actions[$_REQUEST['sa']]))
		fatal_lang_error('no_access', false);

	$sub_actions[$_REQUEST['sa']]['function']();
}

// Get a list of boards and categories used for the jumpto dropdown.
function GetJumpTo()
{
	global $user_info, $context, $smcFunc, $sourcedir;

	// Find the boards/cateogories they can see.
	require_once($sourcedir . '/Subs-MessageIndex.php');
	$boardListOptions = array(
		'use_permissions' => true,
		'selected_board' => isset($context['current_board']) ? $context['current_board'] : 0,
	);
	$context['jump_to'] = getBoardList($boardListOptions);

	// Make the board safe for display.
	foreach ($context['jump_to'] as $id_cat => $cat)
	{
		$context['jump_to'][$id_cat]['name'] = un_htmlspecialchars(strip_tags($cat['name']));
		foreach ($cat['boards'] as $id_board => $board)
			$context['jump_to'][$id_cat]['boards'][$id_board]['name'] = un_htmlspecialchars(strip_tags($board['name']));
	}

	$context['sub_template'] = 'jump_to';
}

function ListMessageIcons()
{
	global $context, $sourcedir, $board;

	require_once($sourcedir . '/Subs-Editor.php');
	$context['icons'] = getMessageIcons($board);

	$context['sub_template'] = 'message_icons';
}

function OrderCustomProfileFields()
{
	global $context, $smcFunc, $modSettings, $txt, $sourcedir;

	// Are you definitely an admin?
	isAllowedTo('admin_forum');
	checkSession('request');

	// Get the positions.
	$old_pos = isset($_REQUEST['old_pos']) ? (int) $_REQUEST['old_pos'] : -1;
	$new_pos = isset($_REQUEST['new_pos']) ? (int) $_REQUEST['new_pos'] : -1;

	// Validate the old and new position data.
	if ($old_pos < 0 || $new_pos < 0 || $old_pos > $modSettings['custom_profile_fields_pos_count'] || $new_pos > $modSettings['custom_profile_fields_pos_count'] || $old_pos == $new_pos)
		obExit(false, false);

	// Try to get the id of the field that we're moving.
	$request = $smcFunc['db_query']('','
		SELECT id_field 
		FROM {db_prefix}custom_fields
		WHERE position = {int:position}',
		array(
			'position' => $old_pos,
		)
	);

	// No result? We can't edit a field that doesn't exist.
	if ($smcFunc['db_num_rows']($request) == 0)
		obExit(false, false);

	list($id_field) = $smcFunc['db_fetch_row']($request);
	$smcFunc['db_free_result']($request);

	// Update the positions in the database.
	// Are we moving the field to a lower position?
	if($new_pos > $old_pos)
	{
		$smcFunc['db_query']('','
			UPDATE {db_prefix}custom_fields
			SET position = position - 1
			WHERE position > {int:old_pos}
				AND position <= {int:new_pos}',
			array(
				'old_pos' => $old_pos - 1,
				'new_pos' => $new_pos,
			)
		);
	}
	// Are we moving the field to a higher position?
	else
	{
		$smcFunc['db_query']('','
			UPDATE {db_prefix}custom_fields
			SET position = position + 1
			WHERE position >= {int:new_pos}
				AND position < {int:old_pos}',
			array(
				'old_pos' => $old_pos,
				'new_pos' => $new_pos,
			)
		);
	}

	// Now move this field into the newly created spot.
	$smcFunc['db_query']('','
		UPDATE {db_prefix}custom_fields
		SET position = {int:new_pos}
		WHERE id_field = {int:id_field}',
		array(
			'id_field' => $id_field,
			'new_pos' => $new_pos,
		)
	);

	// Update the display cache.
	require_once($sourcedir . '/ManageSettings.php');
	RebuildCustomProfileDisplayCache();

	// We aren't returning any data, so we don't need a template, bypass the usual exit method.
	obExit(false, false);
}

?>